from django import forms
from django.utils.translation import ugettext_lazy as _

from .models import User


class MemberEditForm(forms.ModelForm):
    class Meta:
        model = User
        fields = ['email', 'phone', 'mobile', 'groups']
        widgets = {
            'groups': forms.CheckboxSelectMultiple(),
        }


class MemberCreateForm(forms.ModelForm):
    class Meta:
        model = User
        fields = ['first_name', 'last_name', 'email', 'password']
        widgets = {'password': forms.PasswordInput()}


def get_emissions_as_choices():
    from emissions.models import Emission
    return [(None, '')] + [(x.id, x.title) for x in Emission.objects.exclude(archived=True)]


class MemberEmissionForm(forms.Form):
    emission = forms.ChoiceField(
            label=_('New Emission'),
            required=True,
            choices=get_emissions_as_choices)
